@@ -12,7 +12,7 @@ except ImportError:
     except:
         print('subprocess 모듈을 다운받아주세요')
 
-class shell():
+class shell:
     def value(cmd):
         try:
             os.system(f'{cmd}')
